#!/usr/bin/python
#
# -*- coding: utf-8 -*-
# Copyright 2020 Red Hat
# GNU General Public License v3.0+
# (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

#############################################
#                WARNING                    #
#############################################
#
# This file is auto generated by the resource
#   module builder playbook.
#
# Do not edit this file manually.
#
# Changes to this file will be over written
#   by the resource module builder.
#
# Changes should be made in the model used to
#   generate this file or in the resource module
#   builder template.
#
#############################################

"""
The module file for ios_ospfv3
"""

from __future__ import absolute_import, division, print_function


__metaclass__ = type


DOCUMENTATION = """
module: ios_ospfv3
short_description: Resource module to configure OSPFv3.
description:
  This module configures and manages the Open Shortest Path First (OSPF)
  version 3 on IOS platforms.
version_added: 1.1.0
author: Sumit Jaiswal (@justjais)
notes:
  - Tested against Cisco IOSXE Version 17.3 on CML.
  - This module works with connection C(network_cli).
    See U(https://docs.ansible.com/ansible/latest/network/user_guide/platform_ios.html)
options:
  config:
    description: A list of configurations for ospfv3.
    type: dict
    suboptions:
      processes:
        description: List of OSPF instance configurations.
        type: list
        elements: dict
        suboptions:
          process_id:
            description: Process ID
            required: true
            type: int
          address_family:
            description: Enter Address Family command mode
            type: list
            elements: dict
            suboptions:
              afi:
                description: Enter Address Family command mode
                type: str
                choices:
                  - ipv4
                  - ipv6
              unicast:
                description: Address Family modifier
                type: bool
              vrf:
                description: Specify parameters for a VPN Routing/Forwarding instance
                type: str
              adjacency:
                description: Control adjacency formation
                type: dict
                suboptions:
                  min_adjacency:
                    description:
                      - Initial number of adjacencies allowed to be forming in an area
                      - Please refer vendor documentation for valid values
                    type: int
                  none:
                    description: No initial
                    type: bool
                  max_adjacency:
                    description:
                      - Maximum number of adjacencies allowed to be forming
                      - Please refer vendor documentation for valid values
                    type: int
                  disable:
                    description: Disable adjacency staggering
                    type: bool
              areas:
                description: OSPF area parameters
                type: list
                elements: dict
                suboptions:
                  area_id:
                    description:
                      - OSPF area ID as a decimal value. Please refer vendor documentation
                        of Valid values.
                      - OSPF area ID in IP address format(e.g. A.B.C.D)
                    type: str
                  authentication:
                    description: Authentication parameters
                    type: dict
                    suboptions:
                      key_chain:
                        description: Use a key-chain for cryptographic authentication keys
                        type: str
                      "null":
                        description: Use no authentication
                        type: bool
                  default_cost:
                    description:
                      - Set the summary default-cost of a NSSA/stub area
                      - Stub's advertised external route metric
                      - Note, please refer vendor documentation for respective valid values
                    type: int
                  filter_list:
                    description: Filter networks between OSPFv3 areas
                    type: list
                    elements: dict
                    suboptions:
                      name:
                        description: Name of an IP prefix-list
                        type: str
                      direction:
                        description: The direction to apply on the filter networks sent to and from this area.
                        type: str
                        choices: ["in", "out"]
                        required: true
                  normal:
                    description: Specify a normal area type
                    type: bool
                  nssa:
                    description: Specify a NSSA area
                    type: dict
                    suboptions:
                      set:
                        description: Enable a NSSA area
                        type: bool
                      default_information_originate:
                        description: Originate Type 7 default into NSSA area
                        type: dict
                        suboptions:
                          metric:
                            description: OSPF default metric
                            type: int
                          metric_type:
                            description:
                              - OSPF metric type for default routes
                              - OSPF Link State type
                            type: int
                            choices: [1, 2]
                          nssa_only:
                            description: Limit default advertisement to this NSSA area
                            type: bool
                      no_redistribution:
                        description: No redistribution into this NSSA area
                        type: bool
                      no_summary:
                        description: Do not send summary LSA into NSSA
                        type: bool
                      translate:
                        description:
                          - Translate LSA
                          - Always translate LSAs on this ABR
                          - Suppress forwarding address in translated LSAs
                        type: str
                        choices: ["always", "suppress-fa"]
                  ranges:
                    description: Summarize routes matching address/mask (border routers only)
                    type: list
                    elements: dict
                    suboptions:
                      address:
                        description: IP address to match
                        type: str
                      netmask:
                        description: IP mask for address
                        type: str
                      advertise:
                        description:
                          - Advertise this range (default)
                          - Since, advertise when enabled is not shown in running-config
                            idempotency won't be maintained for the play in the second or
                            next run of the play.
                        type: bool
                      cost:
                        description: User specified metric for this range
                        type: int
                      not_advertise:
                        description: DoNotAdvertise this range
                        type: bool
                  sham_link:
                    description: Define a sham link and its parameters
                    type: dict
                    suboptions:
                      source:
                        description: IPv6 address associated with sham-link source (X:X:X:X::X)
                        type: str
                      destination:
                        description: IPv6 address associated with sham-link destination (X:X:X:X::X)
                        type: str
                      authentication:
                        description: Authentication parameters
                        type: dict
                        suboptions:
                          key_chain:
                            description: Use a key-chain for cryptographic authentication keys
                            type: str
                          "null":
                            description: Use no authentication
                            type: bool
                      cost:
                        description:
                          - Associate a cost with the sham-link
                          - Cost of the sham-link
                        type: int
                      ttl_security:
                        description:
                          - TTL security check
                          - maximum number of hops allowed
                        type: int
                  stub:
                    description:
                      - Specify a stub area
                      - Backbone can not be configured as stub area
                    type: dict
                    suboptions:
                      set:
                        description: Enable a stub area
                        type: bool
                      no_summary:
                        description: Do not send summary LSA into stub area
                        type: bool
              authentication:
                description:
                  - Authentication parameters
                  - Authentication operation mode
                type: dict
                suboptions:
                  deployment:
                    description: Deployment mode of operation
                    type: bool
                  normal:
                    description: Normal mode of operation
                    type: bool
              auto_cost:
                description: Calculate OSPF interface cost according to bandwidth
                type: dict
                suboptions:
                  set:
                    description: Enable OSPF auto-cost
                    type: bool
                  reference_bandwidth:
                    description:
                      - Use reference bandwidth method to assign OSPF cost
                      - Note, refer vendor documentation for respective valid values
                    type: int
              bfd:
                description: BFD configuration commands
                type: dict
                suboptions:
                  all_interfaces:
                    description: Enable BFD on all interfaces
                    type: bool
                  disable:
                    description: Disable BFD on all interfaces
                    type: bool
              capability:
                description:
                  - Enable a specific feature
                  - Do not perform PE specific checks
                type: bool
              compatible:
                description: OSPFv3 router compatibility list
                type: dict
                suboptions:
                  rfc1583:
                    description: compatible with RFC 1583
                    type: bool
                  rfc1587:
                    description: compatible with RFC 1587
                    type: bool
                  rfc5243:
                    description: supports DBD exchange optimization
                    type: bool
              default_information:
                description: Control distribution of default information
                type: dict
                suboptions:
                  originate:
                    description: Distribute a default route
                    type: bool
                  always:
                    description: Always advertise default route
                    type: bool
                  metric:
                    description:
                      - OSPF default metric
                      - Note, refer vendor documentation for respective valid values
                    type: int
                  metric_type:
                    description:
                      - OSPF metric type for default routes
                      - Note, please refer vendor documentation for respective valid range
                    type: int
                  route_map:
                    description: Route-map reference name
                    type: str
              default_metric:
                description: Set metric of redistributed routes
                type: int
              discard_route:
                description: Enable or disable discard-route installation
                type: dict
                suboptions:
                  sham_link:
                    description: Discard route for sham-link routes
                    type: bool
                  external:
                    description: Discard route for summarised redistributed routes
                    type: bool
                  internal:
                    description: Discard route for summarised inter-area routes
                    type: bool
              distance:
                description:
                  - Define an administrative distance
                  - Note, please refer vendor documentation for respective valid range
                type: int
              distribute_list:
                description: Filter networks in routing updates
                type: dict
                suboptions:
                  acls:
                    description: IP access list
                    type: list
                    elements: dict
                    suboptions:
                      name:
                        description: IP access list name/number
                        type: str
                        required: true
                      direction:
                        description: Filter incoming and outgoing routing updates.
                        type: str
                        required: true
                        choices: ["in", "out"]
                      interface:
                        description:
                          - Interface configuration (GigabitEthernet A/B)
                          - Valid with incoming traffic
                        type: str
                      protocol:
                        description:
                          - Protocol config (bgp 1).
                          - Valid with outgoing traffic
                        type: str
                  prefix:
                    description: Filter prefixes in routing updates
                    type: dict
                    suboptions:
                      name:
                        description: Name of an IP prefix-list
                        type: str
                        required: true
                      gateway_name:
                        description: Gateway name for filtering incoming updates based on gateway
                        type: str
                      direction:
                        description: Filter incoming and outgoing routing updates.
                        type: str
                        required: true
                        choices: ["in", "out"]
                      interface:
                        description:
                          - Interface configuration (GigabitEthernet A/B)
                          - Valid with incoming traffic
                        type: str
                      protocol:
                        description:
                          - Protocol config (bgp 1).
                          - Valid with outgoing traffic
                        type: str
                  route_map:
                    description: Filter prefixes in routing updates
                    type: dict
                    suboptions:
                      name:
                        description: Route-map name
                        type: str
                        required: true
              event_log:
                description: Event Logging
                type: dict
                suboptions:
                  enable:
                    description: Enable event Logging
                    type: bool
                  one_shot:
                    description: Disable Logging When Log Buffer Becomes Full
                    type: bool
                  pause:
                    description: Pause Event Logging
                    type: bool
                  size:
                    description:
                      - Maximum Number of Events Stored in the Event Log
                      - Note, refer vendor documentation for respective valid values
                    type: int
              graceful_restart:
                description:
                  - Graceful-restart options
                  - helper support
                type: dict
                suboptions:
                  enable:
                    description: helper support enabled
                    type: bool
                  disable:
                    description: disable helper support
                    type: bool
                  strict_lsa_checking:
                    description: enable helper strict LSA checking
                    type: bool
              interface_id:
                description: Source of the interface ID
                type: dict
                suboptions:
                  ios_if_index:
                    description: IOS interface number
                    type: bool
                  snmp_if_index:
                    description: SNMP MIB ifIndex
                    type: bool
              limit:
                description: Limit a specific OSPF feature
                type: dict
                suboptions:
                  dc:
                    description: Demand circuit retransmissions
                    type: dict
                    suboptions:
                      number:
                        description: The maximum number of retransmissions
                        type: int
                      disable:
                        description: Disble the feature
                        type: bool
                  non_dc:
                    description: Non-demand-circuit retransmissions
                    type: dict
                    suboptions:
                      number:
                        description: The maximum number of retransmissions
                        type: int
                      disable:
                        description: Disble the feature
                        type: bool
              local_rib_criteria:
                description: Enable or disable usage of local RIB as route criteria
                type: dict
                suboptions:
                  enable:
                    description: Enable usage of local RIB as route criteria
                    type: bool
                  forwarding_address:
                    description: Local RIB used to validate external/NSSA forwarding addresses
                    type: bool
                  inter_area_summary:
                    description: Local RIB used as criteria for inter-area summaries
                    type: bool
                  nssa_translation:
                    description: Local RIB used as criteria for NSSA translation
                    type: bool
              log_adjacency_changes:
                description: Log changes in adjacency state
                type: dict
                suboptions:
                  set:
                    description: Log changes in adjacency state
                    type: bool
                  detail:
                    description: Log all state changes
                    type: bool
              manet:
                description: Specify MANET OSPF parameters
                type: dict
                suboptions:
                  cache:
                    description: Specify MANET cache sizes
                    type: dict
                    suboptions:
                      acknowledgement:
                        description:
                          - Specify MANET acknowledgement cache size
                          - Maximum number of acknowledgements in cache
                        type: int
                      update:
                        description:
                          - Specify MANET LSA cache size
                          - Maximum number of LSAs in cache
                        type: int
                  hello:
                    description: Unicast Hellos rather than multicast
                    type: dict
                    suboptions:
                      multicast:
                        description: Multicast Hello requests and responses rather than unicast
                        type: bool
                      unicast:
                        description: Unicast Hello requests and responses rather than multicast
                        type: bool
                  peering:
                    description: MANET OSPF Smart Peering
                    type: dict
                    suboptions:
                      set:
                        description: Enable selective peering
                        type: bool
                      disable:
                        description: Disable selective peering
                        type: bool
                      per_interface:
                        description: Select peers per interface rather than per node
                        type: bool
                      redundancy:
                        description:
                          - Redundant paths
                          - Number of redundant OSPF paths
                        type: int
                  willingness:
                    description: Specify and Relay willingness value
                    type: int
              max_lsa:
                description: Maximum number of non self-generated LSAs to accept
                type: dict
                suboptions:
                  number:
                    description:
                      - Maximum number of non self-generated LSAs to accept
                      - Note, refer vendor documentation for respective valid values
                    type: int
                  threshold_value:
                    description:
                      - Threshold value (%) at which to generate a warning msg
                      - Note, refer vendor documentation for respective valid values
                    type: int
                  ignore_count:
                    description:
                      - Maximum number of times adjacencies can be suppressed
                      - Note, refer vendor documentation for respective valid values
                    type: int
                  ignore_time:
                    description:
                      - Number of minutes during which all adjacencies are suppressed
                      - Note, refer vendor documentation for respective valid values
                    type: int
                  reset_time:
                    description:
                      - Number of minutes after which ignore-count is reset to zero
                      - Note, refer vendor documentation for respective valid values
                    type: int
                  warning_only:
                    description: Only give a warning message when limit is exceeded
                    type: bool
              max_metric:
                description:
                  - Set maximum metric
                  - Maximum metric in self-originated router-LSAs
                type: dict
                suboptions:
                  disable:
                    description: disable maximum metric in self-originated router-LSAs
                    type: bool
                  external_lsa:
                    description:
                      - Override external-lsa metric with max-metric value
                      - Overriding metric in external-LSAs
                      - Note, refer vendor documentation for respective valid values
                    type: int
                  inter_area_lsas:
                    description:
                      - Override inter-area-lsas metric with max-metric value
                      - Overriding metric in inter-area-LSAs
                      - Note, refer vendor documentation for respective valid values
                    type: int
                  on_startup:
                    description: Set maximum metric temporarily after reboot
                    type: dict
                    suboptions:
                      time:
                        description:
                          - Time, in seconds, router-LSAs are originated with max-metric
                          - Note, please refer vendor documentation for respective valid range
                        type: int
                      wait_for_bgp:
                        description: Let BGP decide when to originate router-LSA with normal metric
                        type: bool
                  stub_prefix_lsa:
                    description: Set maximum metric for stub links in prefix LSAs
                    type: bool
              maximum_paths:
                description:
                  - Forward packets over multiple paths
                  - Number of paths
                type: int
              passive_interface:
                description: Suppress routing updates on an interface
                type: str
              prefix_suppression:
                description: Prefix suppression
                type: dict
                suboptions:
                  enable:
                    description: Enable prefix suppression
                    type: bool
                  disable:
                    description: Disable prefix suppression
                    type: bool
              queue_depth:
                description: Hello/Router process queue depth
                type: dict
                suboptions:
                  hello:
                    description: OSPF Hello process queue depth
                    type: dict
                    suboptions:
                      max_packets:
                        description: maximum number of packets in the queue
                        type: int
                      unlimited:
                        description: Unlimited queue depth
                        type: bool
                  update:
                    description: OSPF Router process queue depth
                    type: dict
                    suboptions:
                      max_packets:
                        description: maximum number of packets in the queue
                        type: int
                      unlimited:
                        description: Unlimited queue depth
                        type: bool
              router_id:
                description:
                  - Router-id address for this OSPF process
                  - OSPF router-id in IP address format (A.B.C.D)
                type: str
              shutdown:
                description: Shutdown the router process
                type: dict
                suboptions:
                  enable:
                    description: Shutdown the router process
                    type: bool
                  disable:
                    description: Disable Shutdown
                    type: bool
              summary_prefix:
                description: Configure IP address summaries
                type: dict
                suboptions:
                  address:
                    description:
                      - IP summary address (A.B.C.D)
                      - IP prefix <network>/<length> (A.B.C.D/nn)
                    type: str
                  mask:
                    description: IP Summary mask
                    type: str
                  not_advertise:
                    description: Do not advertise or translate
                    type: bool
                  nssa_only:
                    description: Limit summary to NSSA areas
                    type: bool
                  tag:
                    description: Set tag
                    type: int
              timers:
                description: Adjust routing timers
                type: dict
                suboptions:
                  lsa:
                    description:
                      - OSPF LSA timers, arrival timer
                      - The minimum interval in milliseconds between accepting the same LSA
                      - Note, refer vendor documentation for respective valid values
                    type: int
                  manet:
                    description: OSPF MANET timers
                    type: dict
                    suboptions:
                      cache:
                        description: Specify MANET cache sizes
                        type: dict
                        suboptions:
                          acknowledgement:
                            description: Specify MANET acknowledgement cache size
                            type: int
                          redundancy:
                            description: Specify MANET LSA cache size
                            type: int
                      hello:
                        description:
                          - Unicast Hellos rather than multicast
                          - Unicast Hello requests and responses rather than multicast
                        type: bool
                      peering:
                        description: MANET OSPF Smart Peering
                        type: dict
                        suboptions:
                          set:
                            description: Enable selective peering
                            type: bool
                          per_interface:
                            description: Select peers per interface rather than per node
                            type: bool
                          redundancy:
                            description:
                              - Redundant paths
                              - Number of redundant OSPF paths
                            type: int
                      willingness:
                        description: Specify and Relay willingness value
                        type: int
                  pacing:
                    description: OSPF pacing timers
                    type: dict
                    suboptions:
                      flood:
                        description:
                          - OSPF flood pacing timer
                          - The minimum interval in msec to pace limit flooding on interface
                          - Note, refer vendor documentation for respective valid values
                        type: int
                      lsa_group:
                        description:
                          - OSPF LSA group pacing timer
                          - Interval in sec between group of LSA being refreshed or maxaged
                          - Note, refer vendor documentation for respective valid values
                        type: int
                      retransmission:
                        description:
                          - OSPF retransmission pacing timer
                          - The minimum interval in msec between neighbor retransmissions
                          - Note, refer vendor documentation for respective valid values
                        type: int
                  throttle:
                    description: OSPF throttle timers
                    type: dict
                    suboptions:
                      lsa:
                        description: OSPF LSA throttle timers
                        type: dict
                        suboptions:
                          first_delay:
                            description:
                              - Delay to generate first occurrence of LSA in milliseconds
                              - Note, refer vendor documentation for respective valid values
                            type: int
                          min_delay:
                            description:
                              - Minimum delay between originating the same LSA in milliseconds
                              - Note, refer vendor documentation for respective valid values
                            type: int
                          max_delay:
                            description:
                              - Maximum delay between originating the same LSA in milliseconds
                              - Note, refer vendor documentation for respective valid values
                            type: int
                      spf:
                        description: OSPF SPF throttle timers
                          - Delay between receiving a change to SPF calculation in milliseconds
                          - Note, refer vendor documentation for respective valid values
                        type: dict
                        suboptions:
                          receive_delay:
                            description:
                              - Delay between receiving a change to SPF calculation in milliseconds
                              - Note, refer vendor documentation for respective valid values
                            type: int
                          between_delay:
                            description:
                              - Delay between first and second SPF calculation in milliseconds
                              - Note, refer vendor documentation for respective valid values
                            type: int
                          max_delay:
                            description:
                              - Maximum wait time in milliseconds for SPF calculations
                              - Note, refer vendor documentation for respective valid values
                            type: int
          adjacency:
            description: Control adjacency formation
            type: dict
            suboptions:
              min_adjacency:
                description:
                  - Initial number of adjacencies allowed to be forming in an area
                  - Please refer vendor documentation for valid values
                type: int
              max_adjacency:
                description:
                  - Maximum number of adjacencies allowed to be forming
                  - Please refer vendor documentation for valid values
                type: int
              none:
                description: No initial
                type: bool
          areas:
            description: OSPF area parameters
            type: list
            elements: dict
            suboptions:
              area_id:
                description:
                  - OSPF area ID as a decimal value. Please refer vendor documentation
                    of Valid values.
                  - OSPF area ID in IP address format(e.g. A.B.C.D)
                type: str
              authentication:
                description: Authentication parameters
                type: dict
                suboptions:
                  key_chain:
                    description: Use a key-chain for cryptographic authentication keys
                    type: str
                  ipsec:
                    description: Use IPsec authentication
                    type: dict
                    suboptions:
                      spi:
                        description: Set the SPI (Security Parameters Index)
                        type: int
                      md5:
                        description: Use MD5 authentication
                        type: int
                      sha1:
                        description: Use SHA-1 authentication
                        type: int
                      hex_string:
                        description: SHA-1 key (40 chars)
                        type: str
              default_cost:
                description:
                  - Set the summary default-cost of a NSSA/stub area
                  - Stub's advertised external route metric
                  - Note, please refer vendor documentation for respective valid values
                type: int
              nssa:
                description: Specify a NSSA area
                type: dict
                suboptions:
                  set:
                    description: Enable a NSSA area
                    type: bool
                  default_information_originate:
                    description: Originate Type 7 default into NSSA area
                    type: dict
                    suboptions:
                      metric:
                        description: OSPF default metric
                        type: int
                      metric_type:
                        description:
                          - OSPF metric type for default routes
                          - OSPF Link State type
                        type: int
                        choices: [1, 2]
                      nssa_only:
                        description: Limit default advertisement to this NSSA area
                        type: bool
                  no_redistribution:
                    description: No redistribution into this NSSA area
                    type: bool
                  no_summary:
                    description: Do not send summary LSA into NSSA
                    type: bool
                  translate:
                    description:
                      - Translate LSA
                      - Always translate LSAs on this ABR
                      - Suppress forwarding address in translated LSAs
                    type: str
                    choices: ["always", "suppress-fa"]
              stub:
                description:
                  - Specify a stub area
                  - Backbone can not be configured as stub area
                type: dict
                suboptions:
                  set:
                    description: Enable a stub area
                    type: bool
                  no_summary:
                    description: Do not send summary LSA into stub area
                    type: bool
          authentication:
            description:
              - Authentication parameter mode
              - Deployment mode of operation
            type: bool
          auto_cost:
            description: Calculate OSPF interface cost according to bandwidth
            type: dict
            suboptions:
              set:
                description: Enable OSPF auto-cost
                type: bool
              reference_bandwidth:
                description:
                  - Use reference bandwidth method to assign OSPF cost
                  - Note, refer vendor documentation for respective valid values
                type: int
          bfd:
            description:
              - BFD configuration commands
              - Enable BFD on all interfaces
            type: bool
          compatible:
            description: OSPFv3 router compatibility list
            type: dict
            suboptions:
              rfc1583:
                description: compatible with RFC 1583
                type: bool
              rfc1587:
                description: compatible with RFC 1587
                type: bool
              rfc5243:
                description: supports DBD exchange optimization
                type: bool
          event_log:
            description: Event Logging
            type: dict
            suboptions:
              enable:
                description: Enable event Logging
                type: bool
              one_shot:
                description: Disable Logging When Log Buffer Becomes Full
                type: bool
              pause:
                description: Pause Event Logging
                type: bool
              size:
                description:
                  - Maximum Number of Events Stored in the Event Log
                  - Note, refer vendor documentation for respective valid values
                type: int
          graceful_restart:
            description: Graceful-restart options for helper support
            type: dict
            suboptions:
              disable:
                description: disable helper support
                type: bool
              strict_lsa_checking:
                description: enable helper strict LSA checking
                type: bool
          help:
            description: Description of the interactive help system
            type: bool
          interface_id:
            description:
              - Source of the interface ID
              - SNMP MIB ifIndex
            type: bool
          limit:
            description: Limit a specific OSPF feature and LS update, DBD, and LS request retransmissions
            type: dict
            suboptions:
              dc:
                description: Demand circuit retransmissions
                type: dict
                suboptions:
                  number:
                    description: The maximum number of retransmissions
                    type: int
                  disable:
                    description: Disable the feature
                    type: bool
              non_dc:
                description: Non-demand-circuit retransmissions
                type: dict
                suboptions:
                  number:
                    description: The maximum number of retransmissions
                    type: int
                  disable:
                    description: Disable the feature
                    type: bool
          local_rib_criteria:
            description: Enable or disable usage of local RIB as route criteria
            type: dict
            suboptions:
              enable:
                description: Enable usage of local RIB as route criteria
                type: bool
              forwarding_address:
                description: Local RIB used to validate external/NSSA forwarding addresses
                type: bool
              inter_area_summary:
                description: Local RIB used as criteria for inter-area summaries
                type: bool
              nssa_translation:
                description: Local RIB used as criteria for NSSA translation
                type: bool
          log_adjacency_changes:
            description: Log changes in adjacency state
            type: dict
            suboptions:
              set:
                description: Log changes in adjacency state
                type: bool
              detail:
                description: Log all state changes
                type: bool
          manet:
            description: Specify MANET OSPF parameters
            type: dict
            suboptions:
              cache:
                description: Specify MANET cache sizes
                type: dict
                suboptions:
                  acknowledgement:
                    description: Specify MANET acknowledgement cache size
                    type: int
                  redundancy:
                    description: Specify MANET LSA cache size
                    type: int
              hello:
                description:
                  - Unicast Hellos rather than multicast
                  - Unicast Hello requests and responses rather than multicast
                type: bool
              peering:
                description: MANET OSPF Smart Peering
                type: dict
                suboptions:
                  set:
                    description: Enable selective peering
                    type: bool
                  per_interface:
                    description: Select peers per interface rather than per node
                    type: bool
                  redundancy:
                    description:
                      - Redundant paths
                      - Number of redundant OSPF paths
                    type: int
              willingness:
                description: Specify and Relay willingness value
                type: int
          max_lsa:
            description: Maximum number of non self-generated LSAs to accept
            type: dict
            suboptions:
              number:
                description:
                  - Maximum number of non self-generated LSAs to accept
                  - Note, refer vendor documentation for respective valid values
                type: int
              threshold_value:
                description:
                  - Threshold value (%) at which to generate a warning msg
                  - Note, refer vendor documentation for respective valid values
                type: int
              ignore_count:
                description:
                  - Maximum number of times adjacencies can be suppressed
                  - Note, refer vendor documentation for respective valid values
                type: int
              ignore_time:
                description:
                  - Number of minutes during which all adjacencies are suppressed
                  - Note, refer vendor documentation for respective valid values
                type: int
              reset_time:
                description:
                  - Number of minutes after which ignore-count is reset to zero
                  - Note, refer vendor documentation for respective valid values
                type: int
              warning_only:
                description: Only give a warning message when limit is exceeded
                type: bool
          max_metric:
            description: Set maximum metric
            type: dict
            suboptions:
              router_lsa:
                description: Maximum metric in self-originated router-LSAs
                type: bool
                required: true
              external_lsa:
                description:
                  - Override external-lsa metric with max-metric value
                  - Overriding metric in external-LSAs
                  - Note, refer vendor documentation for respective valid values
                type: int
              include_stub:
                description: Set maximum metric for stub links in router-LSAs
                type: bool
              on_startup:
                description: Set maximum metric temporarily after reboot
                type: dict
                suboptions:
                  time:
                    description:
                      - Time, in seconds, router-LSAs are originated with max-metric
                      - Note, please refer vendor documentation for respective valid range
                    type: int
                  wait_for_bgp:
                    description: Let BGP decide when to originate router-LSA with normal metric
                    type: bool
              summary_lsa:
                description:
                  - Override summary-lsa metric with max-metric value
                  - Note, please refer vendor documentation for respective valid range
                type: int
          passive_interface:
            description: Suppress routing updates on an interface
            type: str
          prefix_suppression:
            description: Enable prefix suppression
            type: bool
          queue_depth:
            description: Hello/Router process queue depth
            type: dict
            suboptions:
              hello:
                description: OSPF Hello process queue depth
                type: dict
                suboptions:
                  max_packets:
                    description: maximum number of packets in the queue
                    type: int
                  unlimited:
                    description: Unlimited queue depth
                    type: bool
          router_id:
            description:
              - Router-id address for this OSPF process
              - OSPF router-id in IP address format (A.B.C.D)
            type: str
          shutdown:
            description: Shutdown the router process
            type: bool
          timers:
            description: Adjust routing timers
            type: dict
            suboptions:
              lsa:
                description:
                  - OSPF LSA timers, arrival timer
                  - The minimum interval in milliseconds between accepting the same LSA
                  - Note, refer vendor documentation for respective valid values
                type: int
              manet:
                description: OSPF MANET timers
                type: dict
                suboptions:
                  cache:
                    description: Specify MANET cache sizes
                    type: dict
                    suboptions:
                      acknowledgement:
                        description: Specify MANET acknowledgement cache size
                        type: int
                      redundancy:
                        description: Specify MANET LSA cache size
                        type: int
                  hello:
                    description:
                      - Unicast Hellos rather than multicast
                      - Unicast Hello requests and responses rather than multicast
                    type: bool
                  peering:
                    description: MANET OSPF Smart Peering
                    type: dict
                    suboptions:
                      set:
                        description: Enable selective peering
                        type: bool
                      per_interface:
                        description: Select peers per interface rather than per node
                        type: bool
                      redundancy:
                        description:
                          - Redundant paths
                          - Number of redundant OSPF paths
                        type: int
                  willingness:
                    description: Specify and Relay willingness value
                    type: int
              pacing:
                description: OSPF pacing timers
                type: dict
                suboptions:
                  flood:
                    description:
                      - OSPF flood pacing timer
                      - The minimum interval in msec to pace limit flooding on interface
                      - Note, refer vendor documentation for respective valid values
                    type: int
                  lsa_group:
                    description:
                      - OSPF LSA group pacing timer
                      - Interval in sec between group of LSA being refreshed or maxaged
                      - Note, refer vendor documentation for respective valid values
                    type: int
                  retransmission:
                    description:
                      - OSPF retransmission pacing timer
                      - The minimum interval in msec between neighbor retransmissions
                      - Note, refer vendor documentation for respective valid values
                    type: int
              throttle:
                description: OSPF throttle timers
                type: dict
                suboptions:
                  lsa:
                    description: OSPF LSA throttle timers
                    type: dict
                    suboptions:
                      first_delay:
                        description:
                          - Delay to generate first occurrence of LSA in milliseconds
                          - Note, refer vendor documentation for respective valid values
                        type: int
                      min_delay:
                        description:
                          - Minimum delay between originating the same LSA in milliseconds
                          - Note, refer vendor documentation for respective valid values
                        type: int
                      max_delay:
                        description:
                          - Maximum delay between originating the same LSA in milliseconds
                          - Note, refer vendor documentation for respective valid values
                        type: int
                  spf:
                    description: OSPF SPF throttle timers
                      - Delay between receiving a change to SPF calculation in milliseconds
                      - Note, refer vendor documentation for respective valid values
                    type: dict
                    suboptions:
                      receive_delay:
                        description:
                          - Delay between receiving a change to SPF calculation in milliseconds
                          - Note, refer vendor documentation for respective valid values
                        type: int
                      between_delay:
                        description:
                          - Delay between first and second SPF calculation in milliseconds
                          - Note, refer vendor documentation for respective valid values
                        type: int
                      max_delay:
                        description:
                          - Maximum wait time in milliseconds for SPF calculations
                          - Note, refer vendor documentation for respective valid values
                        type: int
  running_config:
    description:
      - This option is used only with state I(parsed).
      - The value of this option should be the output received from the IOS device by
        executing the command B(sh running-config | section ^router ospfv3).
      - The state I(parsed) reads the configuration from C(running_config) option and
        transforms it into Ansible structured data as per the resource module's argspec
        and the value is then returned in the I(parsed) key within the result.
    type: str
  state:
    description:
      - The state the configuration should be left in
      - The states I(rendered), I(gathered) and I(parsed) does not perform any change
        on the device.
      - The state I(rendered) will transform the configuration in C(config) option to
        platform specific CLI commands which will be returned in the I(rendered) key
        within the result. For state I(rendered) active connection to remote host is
        not required.
      - The state I(gathered) will fetch the running configuration from device and transform
        it into structured data in the format as per the resource module argspec and
        the value is returned in the I(gathered) key within the result.
      - The state I(parsed) reads the configuration from C(running_config) option and
        transforms it into JSON format as per the resource module parameters and the
        value is returned in the I(parsed) key within the result. The value of C(running_config)
        option should be the same format as the output of command I(show running-config
        | include ip route|ipv6 route) executed on device. For state I(parsed) active
        connection to remote host is not required.
    type: str
    choices:
      - merged
      - replaced
      - overridden
      - deleted
      - gathered
      - parsed
      - rendered
    default: merged
"""

EXAMPLES = """

# Using merged

# Before state:
# -------------
#
# router-ios#sh running-config | section ^router ospfv3
# router-ios#

- name: Merge provided OSPFV3 configuration
  cisco.ios.ios_ospfv3:
    config:
      processes:
        - process_id: 1
          max_metric:
            router_lsa: true
            on_startup:
              time: 110
          address_family:
            - afi: ipv4
              unicast: true
              vrf: blue
              adjacency:
                min_adjacency: 50
                max_adjacency: 50
              areas:
                - area_id: 25
                  nssa:
                    default_information_originate:
                      metric: 25
                      nssa_only: true
          areas:
            - area_id: "10"
              nssa:
                default_information_originate:
                  metric: 10
          timers:
            throttle:
              lsa:
                first_delay: 12
                min_delay: 14
                max_delay: 16
        - process_id: 200
          address_family:
            - afi: ipv4
              unicast: true
              adjacency:
                min_adjacency: 200
                max_adjacency: 200
          max_metric:
            router_lsa: true
            on_startup:
              time: 100
          auto_cost:
            reference_bandwidth: 4
    state: merged

# Task Output:
# ------------

# before: {}
#
# commands:
# - router ospfv3 1
# - max-metric router-lsa on-startup 110
# - area 10 nssa default-information-originate metric 10
# - address-family ipv4 unicast vrf blue
# - adjacency stagger 50 50
# - area 25 nssa default-information-originate metric 25 nssa-only
# - exit-address-family
# - router ospfv3 200
# - auto-cost reference-bandwidth 4
# - max-metric router-lsa on-startup 100
# - address-family ipv4 unicast
# - adjacency stagger 200 200
# - exit-address-family
#
# after:
#     processes:
#     - address_family:
#       - adjacency:
#           max_adjacency: 50
#           min_adjacency: 50
#         afi: ipv4
#         areas:
#         - area_id: '25'
#           nssa:
#             default_information_originate:
#               metric: 25
#               nssa_only: true
#         unicast: true
#         vrf: blue
#       areas:
#       - area_id: '10'
#         nssa:
#           default_information_originate:
#             metric: 10
#       max_metric:
#         on_startup:
#           time: 110
#         router_lsa: true
#       process_id: 1
#     - address_family:
#       - adjacency:
#           max_adjacency: 200
#           min_adjacency: 200
#         afi: ipv4
#         unicast: true
#       auto_cost:
#         reference_bandwidth: 4
#       max_metric:
#         on_startup:
#           time: 100
#         router_lsa: true
#       process_id: 200

# After state:
# -------------
#
# router-ios#sh running-config | section ^router ospfv3
# router ospfv3 1
#  max-metric router-lsa on-startup 110
#  area 10 nssa default-information-originate metric 10
#  !
#  address-family ipv4 unicast vrf blue
#   adjacency stagger 50 50
#   area 25 nssa default-information-originate metric 25 nssa-only
#  exit-address-family
# router ospfv3 200
#  max-metric router-lsa on-startup 100
#  auto-cost reference-bandwidth 4
#  !
#  address-family ipv4 unicast
#   adjacency stagger 200 200
#  exit-address-family

# Using deleted

# Before state:
# -------------
#
# router-ios#sh running-config | section ^router ospfv3
# router ospfv3 1
#  max-metric router-lsa on-startup 110
#  area 10 nssa default-information-originate metric 10
#  !
#  address-family ipv4 unicast vrf blue
#   adjacency stagger 50 50
#   area 25 nssa default-information-originate metric 25 nssa-only
#  exit-address-family
# router ospfv3 200
#  max-metric router-lsa on-startup 100
#  auto-cost reference-bandwidth 4
#  !
#  address-family ipv4 unicast
#   adjacency stagger 200 200
#  exit-address-family

- name: Delete provided OSPF V3 processes
  cisco.ios.ios_ospfv3:
    config:
      processes:
        - process_id: 1
    state: deleted

# Task Output:
# ------------

# before:
#     processes:
#     - address_family:
#       - adjacency:
#           max_adjacency: 50
#           min_adjacency: 50
#         afi: ipv4
#         areas:
#         - area_id: '25'
#           nssa:
#             default_information_originate:
#               metric: 25
#               nssa_only: true
#         unicast: true
#         vrf: blue
#       areas:
#       - area_id: '10'
#         nssa:
#           default_information_originate:
#             metric: 10
#       max_metric:
#         on_startup:
#           time: 110
#         router_lsa: true
#       process_id: 1
#     - address_family:
#       - adjacency:
#           max_adjacency: 200
#           min_adjacency: 200
#         afi: ipv4
#         unicast: true
#       auto_cost:
#         reference_bandwidth: 4
#       max_metric:
#         on_startup:
#           time: 100
#         router_lsa: true
#       process_id: 200
#
# commands:
# - no router ospfv3 1
#
# parsed:
#     processes:
#     - address_family:
#       - adjacency:
#           max_adjacency: 200
#           min_adjacency: 200
#         afi: ipv4
#         unicast: true
#       auto_cost:
#         reference_bandwidth: 4
#       max_metric:
#         on_startup:
#           time: 100
#         router_lsa: true
#       process_id: 200
#
# After state:
# ------------
# router-ios#sh running-config | section ^router ospfv3
# router ospfv3 200
#  max-metric router-lsa on-startup 100
#  auto-cost reference-bandwidth 4
#  !
#  address-family ipv4 unicast
#   adjacency stagger 200 200
#  exit-address-family

# Using deleted without any config passed (NOTE: This will delete all OSPFV3 configuration from device)

# Before state:
# -------------
#
# router-ios#sh running-config | section ^router ospfv3
# router ospfv3 1
#  max-metric router-lsa on-startup 110
#  area 10 nssa default-information-originate metric 10
#  !
#  address-family ipv4 unicast vrf blue
#   adjacency stagger 50 50
#   area 25 nssa default-information-originate metric 25 nssa-only
#  exit-address-family
# router ospfv3 200
#  max-metric router-lsa on-startup 100
#  auto-cost reference-bandwidth 4
#  !
#  address-family ipv4 unicast
#   adjacency stagger 200 200
#  exit-address-family

- name: Delete all OSPF processes
  cisco.ios.ios_ospfv3:
    state: deleted

# Task Output:
# ------------

# before:
#     processes:
#     - address_family:
#       - adjacency:
#           max_adjacency: 50
#           min_adjacency: 50
#         afi: ipv4
#         areas:
#         - area_id: '25'
#           nssa:
#             default_information_originate:
#               metric: 25
#               nssa_only: true
#         unicast: true
#         vrf: blue
#       areas:
#       - area_id: '10'
#         nssa:
#           default_information_originate:
#             metric: 10
#       max_metric:
#         on_startup:
#           time: 110
#         router_lsa: true
#       process_id: 1
#     - address_family:
#       - adjacency:
#           max_adjacency: 200
#           min_adjacency: 200
#         afi: ipv4
#         unicast: true
#       auto_cost:
#         reference_bandwidth: 4
#       max_metric:
#         on_startup:
#           time: 100
#         router_lsa: true
#       process_id: 200
#
# commands:
# - no router ospfv3 200
# - no router ospfv3 1
#
# after: {}
#
# After state:
# ------------
# router-ios#sh running-config | section ^router ospfv3
# router-ios#


# Using overridden

# Before state:
# -------------
#
# router ospfv3 1
#  max-metric router-lsa on-startup 110
#  area 10 nssa default-information-originate metric 10
#  !
#  address-family ipv4 unicast vrf blue
#   adjacency stagger 50 50
#   area 25 nssa default-information-originate metric 25 nssa-only
#  exit-address-family
# router ospfv3 200
#  max-metric router-lsa on-startup 100
#  auto-cost reference-bandwidth 4
#  !
#  address-family ipv4 unicast
#   adjacency stagger 200 200
#  exit-address-family

- name: Override provided OSPFV3 configuration
  cisco.ios.ios_ospfv3:
    config:
      processes:
        - process_id: 200
          max_metric:
            router_lsa: true
            on_startup:
              time: 200
          address_family:
            - afi: ipv4
              unicast: true
              adjacency:
                min_adjacency: 50
                max_adjacency: 50
              areas:
                - area_id: 200
                  nssa:
                    default_information_originate:
                      metric: 200
                      nssa_only: true
          areas:
            - area_id: "10"
              nssa:
                default_information_originate:
                  metric: 10
    state: overridden

# Task Output:
# ------------

# before:
#     processes:
#     - address_family:
#       - adjacency:
#           max_adjacency: 50
#           min_adjacency: 50
#         afi: ipv4
#         areas:
#         - area_id: '25'
#           nssa:
#             default_information_originate:
#               metric: 25
#               nssa_only: true
#         unicast: true
#         vrf: blue
#       areas:
#       - area_id: '10'
#         nssa:
#           default_information_originate:
#             metric: 10
#       max_metric:
#         on_startup:
#           time: 110
#         router_lsa: true
#       process_id: 1
#     - address_family:
#       - adjacency:
#           max_adjacency: 200
#           min_adjacency: 200
#         afi: ipv4
#         unicast: true
#       auto_cost:
#         reference_bandwidth: 4
#       max_metric:
#         on_startup:
#           time: 100
#         router_lsa: true
#       process_id: 200
#
# commands:
# - no router ospfv3 1
# - router ospfv3 200
# - no auto-cost reference-bandwidth 4
# - max-metric router-lsa on-startup 200
# - area 10 nssa default-information-originate metric 10
# - address-family ipv4 unicast
# - adjacency stagger 50 50
# - area 200 nssa default-information-originate metric 200 nssa-only
# - exit-address-family
#
# after:
#     processes:
#     - address_family:
#       - adjacency:
#           max_adjacency: 50
#           min_adjacency: 50
#         afi: ipv4
#         areas:
#         - area_id: '200'
#           nssa:
#             default_information_originate:
#               metric: 200
#               nssa_only: true
#         unicast: true
#       areas:
#       - area_id: '10'
#         nssa:
#           default_information_originate:
#             metric: 10
#       max_metric:
#         on_startup:
#           time: 200
#         router_lsa: true
#       process_id: 200

# After state:
# ------------
#
# router-ios#sh running-config | section ^router ospfv3
# router ospfv3 200
#  max-metric router-lsa on-startup 200
#  area 10 nssa default-information-originate metric 10
#  !
#  address-family ipv4 unicast
#   adjacency stagger 50 50
#   area 200 nssa default-information-originate metric 200 nssa-only
#  exit-address-family

# Using replaced

# Before state:
# -------------
#
# router-ios#sh running-config | section ^router ospfv3
# router ospfv3 1
#  max-metric router-lsa on-startup 110
#  area 10 nssa default-information-originate metric 10
#  !
#  address-family ipv4 unicast vrf blue
#   adjacency stagger 50 50
#   area 25 nssa default-information-originate metric 25 nssa-only
#  exit-address-family
# router ospfv3 200
#  max-metric router-lsa on-startup 100
#  auto-cost reference-bandwidth 4
#  !
#  address-family ipv4 unicast
#   adjacency stagger 200 200
#  exit-address-family

- name: Perform replace with provided configurations.
  cisco.ios.ios_ospfv3:
    config:
      processes:
        - process_id: 200
          max_metric:
            router_lsa: true
            on_startup:
              time: 200
          address_family:
            - afi: ipv4
              unicast: true
              adjacency:
                min_adjacency: 50
                max_adjacency: 50
              areas:
                - area_id: 200
                  nssa:
                    default_information_originate:
                      metric: 200
                      nssa_only: true
          areas:
            - area_id: "10"
              nssa:
                default_information_originate:
                  metric: 10
    state: replaced

# Task Output:
# ------------

# before:
#     processes:
#     - address_family:
#       - adjacency:
#           max_adjacency: 50
#           min_adjacency: 50
#         afi: ipv4
#         areas:
#         - area_id: '25'
#           nssa:
#             default_information_originate:
#               metric: 25
#               nssa_only: true
#         unicast: true
#         vrf: blue
#       areas:
#       - area_id: '10'
#         nssa:
#           default_information_originate:
#             metric: 10
#       max_metric:
#         on_startup:
#           time: 110
#         router_lsa: true
#       process_id: 1
#     - address_family:
#       - adjacency:
#           max_adjacency: 200
#           min_adjacency: 200
#         afi: ipv4
#         unicast: true
#       auto_cost:
#         reference_bandwidth: 4
#       max_metric:
#         on_startup:
#           time: 100
#         router_lsa: true
#       process_id: 200
#
# commands:
# - router ospfv3 200
# - no auto-cost reference-bandwidth 4
# - max-metric router-lsa on-startup 200
# - area 10 nssa default-information-originate metric 10
# - address-family ipv4 unicast
# - adjacency stagger 50 50
# - area 200 nssa default-information-originate metric 200 nssa-only
# - exit-address-family
#
# after:
#     processes:
#     - address_family:
#       - adjacency:
#           max_adjacency: 50
#           min_adjacency: 50
#         afi: ipv4
#         areas:
#         - area_id: '25'
#           nssa:
#             default_information_originate:
#               metric: 25
#               nssa_only: true
#         unicast: true
#         vrf: blue
#       areas:
#       - area_id: '10'
#         nssa:
#           default_information_originate:
#             metric: 10
#       max_metric:
#         on_startup:
#           time: 110
#         router_lsa: true
#       process_id: 1
#     - address_family:
#       - afi: ipv4
#         areas:
#         - area_id: '200'
#           nssa:
#             default_information_originate:
#               metric: 200
#               nssa_only: true
#         unicast: true
#       areas:
#       - area_id: '10'
#         nssa:
#           default_information_originate:
#             metric: 10
#       max_metric:
#         on_startup:
#           time: 200
#         router_lsa: true
#       process_id: 200
#
# After state:
# -------------
# router-ios#sh running-config | section ^router ospfv3
# router ospfv3 1
#  max-metric router-lsa on-startup 110
#  area 10 nssa default-information-originate metric 10
#  !
#  address-family ipv4 unicast vrf blue
#   adjacency stagger 50 50
#   area 25 nssa default-information-originate metric 25 nssa-only
#  exit-address-family
# router ospfv3 200
#  max-metric router-lsa on-startup 200
#  area 10 nssa default-information-originate metric 10
#  !
#  address-family ipv4 unicast
#   adjacency stagger 50 50
#   area 200 nssa default-information-originate metric 200 nssa-only
#  exit-address-family

# Using Gathered

# Before state:
# -------------
#
# router-ios#sh running-config | section ^router ospfv3
# router ospfv3 1
#  max-metric router-lsa on-startup 110
#  area 10 nssa default-information-originate metric 10
#  !
#  address-family ipv4 unicast vrf blue
#   adjacency stagger 50 50
#   area 25 nssa default-information-originate metric 25 nssa-only
#  exit-address-family
# router ospfv3 200
#  max-metric router-lsa on-startup 100
#  auto-cost reference-bandwidth 4
#  !
#  address-family ipv4 unicast
#   adjacency stagger 200 200
#  exit-address-family

- name: Gather OSPFV3 provided configurations
  cisco.ios.ios_ospfv3:
    config:
    state: gathered

# Task Output:
# ------------
#
# parsed:
#     processes:
#     - address_family:
#       - adjacency:
#           max_adjacency: 50
#           min_adjacency: 50
#         afi: ipv4
#         areas:
#         - area_id: '25'
#           nssa:
#             default_information_originate:
#               metric: 25
#               nssa_only: true
#         unicast: true
#         vrf: blue
#       areas:
#       - area_id: '10'
#         nssa:
#           default_information_originate:
#             metric: 10
#       max_metric:
#         on_startup:
#           time: 110
#         router_lsa: true
#       process_id: 1
#     - address_family:
#       - adjacency:
#           max_adjacency: 200
#           min_adjacency: 200
#         afi: ipv4
#         unicast: true
#       auto_cost:
#         reference_bandwidth: 4
#       max_metric:
#         on_startup:
#           time: 100
#         router_lsa: true
#       process_id: 200

# After state:
# ------------
#
# router-ios#sh running-config | section ^router ospfv3
# router ospfv3 1
#  max-metric router-lsa on-startup 110
#  area 10 nssa default-information-originate metric 10
#  !
#  address-family ipv4 unicast vrf blue
#   adjacency stagger 50 50
#   area 25 nssa default-information-originate metric 25 nssa-only
#  exit-address-family
# router ospfv3 200
#  max-metric router-lsa on-startup 100
#  auto-cost reference-bandwidth 4
#  !
#  address-family ipv4 unicast
#   adjacency stagger 200 200
#  exit-address-family

# Using Rendered

- name: Render the commands for provided  configuration
  cisco.ios.ios_ospfv3:
    config:
      processes:
        - process_id: 1
          max_metric:
            router_lsa: true
            on_startup:
              time: 110
          address_family:
            - afi: ipv4
              unicast: true
              vrf: blue
              adjacency:
                min_adjacency: 50
                max_adjacency: 50
              areas:
                - area_id: 25
                  nssa:
                    default_information_originate:
                      metric: 25
                      nssa_only: true
          areas:
            - area_id: "10"
              nssa:
                default_information_originate:
                  metric: 10
          timers:
            throttle:
              lsa:
                first_delay: 12
                min_delay: 14
                max_delay: 16
        - process_id: 200
          address_family:
            - afi: ipv4
              unicast: true
              adjacency:
                min_adjacency: 200
                max_adjacency: 200
          max_metric:
            router_lsa: true
            on_startup:
              time: 100
          auto_cost:
            reference_bandwidth: 4
    state: rendered

# Task Output:
# ------------

# rendered:
# - router ospfv3 1
# - max-metric router-lsa on-startup 110
# - area 10 nssa default-information-originate metric 10
# - address-family ipv4 unicast vrf blue
# - adjacency stagger 50 50
# - area 25 nssa default-information-originate metric 25 nssa-only
# - exit-address-family
# - router ospfv3 200
# - auto-cost reference-bandwidth 4
# - max-metric router-lsa on-startup 100
# - address-family ipv4 unicast
# - adjacency stagger 200 200
# - exit-address-family


# Using Parsed

# File: parsed.cfg
# ----------------
#
# router ospfv3 1
#  max-metric router-lsa on-startup 110
#  area 10 nssa default-information-originate metric 10
#  !
#  address-family ipv4 unicast vrf blue
#   adjacency stagger 50 50
#   area 25 nssa default-information-originate metric 25 nssa-only
#  exit-address-family
# router ospfv3 200
#  max-metric router-lsa on-startup 100
#  auto-cost reference-bandwidth 4
#  !
#  address-family ipv4 unicast
#   adjacency stagger 200 200
#  exit-address-family

- name: Parse the provided configuration and display structured ospfv3 facts.
  cisco.ios.ios_ospfv3:
    running_config: "{{ lookup('file', 'parsed.cfg') }}"
    state: parsed

# Task Output:
# ------------
#
# parsed:
#     processes:
#     - address_family:
#       - adjacency:
#           max_adjacency: 50
#           min_adjacency: 50
#         afi: ipv4
#         areas:
#         - area_id: '25'
#           nssa:
#             default_information_originate:
#               metric: 25
#               nssa_only: true
#         unicast: true
#         vrf: blue
#       areas:
#       - area_id: '10'
#         nssa:
#           default_information_originate:
#             metric: 10
#       max_metric:
#         on_startup:
#           time: 110
#         router_lsa: true
#       process_id: 1
#     - address_family:
#       - adjacency:
#           max_adjacency: 200
#           min_adjacency: 200
#         afi: ipv4
#         unicast: true
#       auto_cost:
#         reference_bandwidth: 4
#       max_metric:
#         on_startup:
#           time: 100
#         router_lsa: true
#       process_id: 200
"""

RETURN = """
before:
  description: The configuration prior to the model invocation.
  returned: always
  sample: >
    The configuration returned will always be in the same format
     of the parameters above.
  type: dict
after:
  description: The resulting configuration model invocation.
  returned: when changed
  sample: >
    The configuration returned will always be in the same format
     of the parameters above.
  type: dict
commands:
  description: The set of commands pushed to the remote device.
  returned: always
  type: list
  sample: ['router ospfv3 1', 'address-family ipv4 unicast vrf blue', 'adjacency stagger 50 50']
rendered:
  description: The provided configuration in the task rendered in device-native format (offline).
  returned: when I(state) is C(rendered)
  type: list
  sample:
    - router ospfv3 1
    - max-metric router-lsa on-startup 110
    - area 10 nssa default-information-originate metric 10
gathered:
  description: Facts about the network resource gathered from the remote device as structured data.
  returned: when I(state) is C(gathered)
  type: dict
  sample: >
    This output will always be in the same format as the
    module argspec.
parsed:
  description: The device native config provided in I(running_config) option parsed into structured data as per module argspec.
  returned: when I(state) is C(parsed)
  type: dict
  sample: >
    This output will always be in the same format as the
    module argspec.
"""


from ansible.module_utils.basic import AnsibleModule

from ansible_collections.cisco.ios.plugins.module_utils.network.ios.argspec.ospfv3.ospfv3 import (
    Ospfv3Args,
)
from ansible_collections.cisco.ios.plugins.module_utils.network.ios.config.ospfv3.ospfv3 import (
    Ospfv3,
)


def main():
    """
    Main entry point for module execution
    :returns: the result form module invocation
    """
    required_if = [
        ("state", "merged", ("config",)),
        ("state", "replaced", ("config",)),
        ("state", "overridden", ("config",)),
        ("state", "rendered", ("config",)),
        ("state", "parsed", ("running_config",)),
    ]

    mutually_exclusive = [("config", "running_config")]

    module = AnsibleModule(
        argument_spec=Ospfv3Args.argument_spec,
        required_if=required_if,
        mutually_exclusive=mutually_exclusive,
        supports_check_mode=True,
    )

    result = Ospfv3(module).execute_module()
    module.exit_json(**result)


if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-
# Copyright 2020 Red Hat
# GNU General Public License v3.0+
# (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import absolute_import, division, print_function


__metaclass__ = type

"""
The eos ospf_interfaces fact class
It is in this file the configuration is collected from the device
for a given resource, parsed, and the facts tree is populated
based on the configuration.
"""

import re

from ansible_collections.ansible.netcommon.plugins.module_utils.network.common import utils

from ansible_collections.arista.eos.plugins.module_utils.network.eos.argspec.ospf_interfaces.ospf_interfaces import (
    Ospf_interfacesArgs,
)
from ansible_collections.arista.eos.plugins.module_utils.network.eos.rm_templates.ospf_interfaces import (
    Ospf_interfacesTemplate,
)


class Ospf_interfacesFacts(object):
    """The eos ospf_interfaces facts class"""

    def __init__(self, module, subspec="config", options="options"):
        self._module = module
        self.argument_spec = Ospf_interfacesArgs.argument_spec

    def get_config(self, connection):
        """Wrapper method for `connection.get()`
        This method exists solely to allow the unit test framework to mock device connection calls.
        """
        return connection.get("show running-config | section interface ")

    def populate_facts(self, connection, ansible_facts, data=None):
        """Populate the facts for Ospf_interfaces network resource

        :param connection: the device connection
        :param ansible_facts: Facts dictionary
        :param data: previously collected conf

        :rtype: dictionary
        :returns: facts
        """
        facts = {}

        if not data:
            data = self.get_config(connection)

        resource_delim = "interface"
        find_pattern = r"(?:^|\n)%s.*?(?=(?:^|\n)%s|$)" % (
            resource_delim,
            resource_delim,
        )
        resources = [p.strip() for p in re.findall(find_pattern, data, re.DOTALL)]
        # parse native config using the Ospf_interfaces template
        ospf_interfaces_facts = []
        for resource in resources:
            ospf_interfaces_parser = Ospf_interfacesTemplate(
                lines=resource.splitlines(),
                module=self._module,
            )
            entry = ospf_interfaces_parser.parse()
            if entry:
                if "address_family" in entry and entry["address_family"]:
                    entry["address_family"] = sorted(
                        list(entry["address_family"].values()),
                        key=lambda k, sk="afi": k[sk],
                    )
            if entry:
                if entry.get("address_family"):
                    for addr in entry["address_family"]:
                        if "ip_params" in addr:
                            addr["ip_params"] = sorted(
                                list(addr["ip_params"].values()),
                                key=lambda k, sk="afi": k[sk],
                            )
            ospf_interfaces_facts.append(entry)

        ansible_facts["ansible_network_resources"].pop("ospf_interfaces", None)
        facts = {"ospf_interfaces": []}
        params = utils.remove_empties(
            ospf_interfaces_parser.validate_config(
                self.argument_spec,
                {"config": ospf_interfaces_facts},
                redact=True,
            ),
        )

        if params.get("config"):
            for cfg in params["config"]:
                facts["ospf_interfaces"].append(utils.remove_empties(cfg))
        ansible_facts["ansible_network_resources"].update(facts)

        return ansible_facts



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)


DOCUMENTATION = r"""
---
module: reports_view_group_view_info
short_description: Information module for Reports View Group View Info
description:
- This module represents an alias of the module reports_view_group_view_v1_info
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  viewGroupId:
    description:
    - ViewGroupId path parameter. ViewGroupId of viewgroup.
    type: str
  viewId:
    description:
    - ViewId path parameter. View id of view.
    type: str
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for Reports GetViewDetailsForAGivenViewGroup_ViewV1
  description: Complete reference of the GetViewDetailsForAGivenViewGroup_ViewV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!get-view-details-for-a-given-view-group-view
notes:
  - SDK Method used are
    reports.Reports.get_view_details_for_a_given_view_group_and_view,

  - Paths used are
    get /dna/intent/api/v1/data/view-groups/{viewGroupId}/views/{viewId},
  - It should be noted that this module is an alias of reports_view_group_view_v1_info

"""

EXAMPLES = r"""
- name: Get Reports View Group View Info by id
  cisco.dnac.reports_view_group_view_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    viewGroupId: string
    viewId: string
  register: result

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "deliveries": [
        {
          "type": "string",
          "default": true
        }
      ],
      "description": "string",
      "fieldGroups": [
        {
          "fieldGroupDisplayName": "string",
          "fieldGroupName": "string",
          "fields": [
            {
              "displayName": "string",
              "name": "string"
            }
          ],
          "tableId": "string"
        }
      ],
      "filters": [
        {
          "additionalInfo": {},
          "cacheFilter": true,
          "dataType": "string",
          "displayName": "string",
          "filterSource": {
            "dataSource": {},
            "displayValuePath": "string",
            "rootPath": "string",
            "valuePath": "string"
          },
          "name": "string",
          "required": true,
          "timeOptions": [
            {
              "info": "string",
              "maxValue": 0,
              "minValue": 0,
              "name": "string",
              "value": "string"
            }
          ],
          "type": "string"
        }
      ],
      "formats": [
        {
          "format": "string",
          "name": "string",
          "default": true,
          "template": {
            "jsTemplateId": "string"
          }
        }
      ],
      "schedules": [
        {
          "type": "string",
          "default": true
        }
      ],
      "viewId": "string",
      "viewInfo": "string",
      "viewName": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: site_wise_product_names_count_v1_info
short_description: Information module for Site Wise Product Names Count V1
description:
- Get all Site Wise Product Names Count V1.
- Returns the count of network device product names for given filters. The default value of `siteId` is global.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  siteId:
    description:
    - >
      SiteId query parameter. Site identifier to get the list of all available products under the site. The
      default value is global site id. See https //developer.cisco.com/docs/dna-center/get-site/ for siteId.
    type: str
  productName:
    description:
    - >
      ProductName query parameter. Filter with network device product name. Supports partial case-insensitive
      search. A minimum of 3 characters are required for search.
    type: str
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for Software Image Management (SWIM) ReturnsTheCountOfNetworkDeviceProductNamesForASiteV1
  description: Complete reference of the ReturnsTheCountOfNetworkDeviceProductNamesForASiteV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!returns-the-count-of-network-device-product-names-for-a-site
notes:
  - SDK Method used are
    software_image_management_swim.SoftwareImageManagementSwim.returns_the_count_of_network_device_product_names_for_a_site_v1,

  - Paths used are
    get /dna/intent/api/v1/siteWiseProductNames/count,

"""

EXAMPLES = r"""
- name: Get all Site Wise Product Names Count V1
  cisco.dnac.site_wise_product_names_count_v1_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    siteId: string
    productName: string
  register: result

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-
#
# Ansible module to manage CheckPoint Firewall (c) 2019
#
# Ansible is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Ansible is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Ansible.  If not, see <http://www.gnu.org/licenses/>.
#

from __future__ import absolute_import, division, print_function

__metaclass__ = type

ANSIBLE_METADATA = {
    "metadata_version": "1.1",
    "status": ["preview"],
    "supported_by": "community",
}

DOCUMENTATION = """
---
module: cp_mgmt_check_network_feed
short_description: Check if a target can reach or parse a network feed; can work with an existing feed object or with a
                   new one (by providing all relevant feed parameters).
description:
  - Check if a target can reach or parse a network feed; can work with an existing feed object or with a new one (by providing all relevant feed parameters).
  - All operations are performed over Web Services API.
version_added: "3.0.0"
author: "Eden Brillant (@chkp-edenbr)"
options:
  targets:
    description:
      - On what targets to execute this command. Targets may be identified by their name, or object unique identifier.
    type: list
    elements: str
  network_feed:
    description:
      - network feed parameters.
    type: dict
    suboptions:
      name:
        description:
          - Object name.
        type: str
      feed_url:
        description:
          - URL of the feed. URL should be written as http or https.
        type: str
      certificate_id:
        description:
          - Certificate SHA-1 fingerprint to access the feed.
        type: str
      feed_format:
        description:
          - Feed file format.
        type: str
        choices: ['Flat List', 'JSON']
      feed_type:
        description:
          - Feed type to be enforced.
        type: str
        choices: ['Domain', 'IP Address', 'IP Address/Domain']
      password:
        description:
          - password for authenticating with the URL.
        type: str
      username:
        description:
          - username for authenticating with the URL.
        type: str
      custom_header:
        description:
          - Headers to allow different authentication methods with the URL.
        type: list
        elements: dict
        suboptions:
          header_name:
            description:
              - The name of the HTTP header we wish to add.
            type: str
          header_value:
            description:
              - The name of the HTTP value we wish to add.
            type: str
      update_interval:
        description:
          - Interval in minutes for updating the feed on the Security Gateway.
        type: int
      data_column:
        description:
          - Number of the column that contains the feed's data.
        type: int
      fields_delimiter:
        description:
          - The delimiter that separates between the columns in the feed.
        type: str
      ignore_lines_that_start_with:
        description:
          - A prefix that will determine which lines to ignore.
        type: str
      json_query:
        description:
          - JQ query to be parsed.
        type: str
      use_gateway_proxy:
        description:
          - Use the gateway's proxy for retrieving the feed.
        type: bool
      details_level:
        description:
          - The level of detail for some of the fields in the response can vary from showing only the UID value of the object to a fully detailed
            representation of the object.
        type: str
        choices: ['uid', 'standard', 'full']
      domains_to_process:
        description:
          - Indicates which domains to process the commands on. It cannot be used with the details-level full, must be run from the System Domain
            only and with ignore-warnings true. Valid values are, CURRENT_DOMAIN, ALL_DOMAINS_ON_THIS_SERVER.
        type: list
        elements: str
      ignore_warnings:
        description:
          - Apply changes ignoring warnings.
        type: bool
      ignore_errors:
        description:
          - Apply changes ignoring errors. You won't be able to publish such a changes. If ignore-warnings flag was omitted - warnings will also be ignored.
        type: bool
  auto_publish_session:
    description:
      - Publish the current session if changes have been performed after task completes.
    type: bool
extends_documentation_fragment: check_point.mgmt.checkpoint_commands
"""

EXAMPLES = """
- name: check-network-feed
  cp_mgmt_check_network_feed:
    network_feed:
      name: existing_feed
    targets: corporate-gateway
"""

RETURN = """
cp_mgmt_check_network_feed:
  description: The checkpoint check-network-feed output.
  returned: always.
  type: dict
"""

from ansible.module_utils.basic import AnsibleModule
from ansible_collections.check_point.mgmt.plugins.module_utils.checkpoint import (
    checkpoint_argument_spec_for_commands,
    api_command,
)


def main():
    argument_spec = dict(
        targets=dict(type="list", elements="str"),
        network_feed=dict(
            type="dict",
            options=dict(
                name=dict(type="str"),
                feed_url=dict(type="str"),
                certificate_id=dict(type="str"),
                feed_format=dict(type="str", choices=["Flat List", "JSON"]),
                feed_type=dict(
                    type="str",
                    choices=["Domain", "IP Address", "IP Address/Domain"],
                ),
                password=dict(type="str", no_log=True),
                username=dict(type="str"),
                custom_header=dict(
                    type="list",
                    elements="dict",
                    options=dict(
                        header_name=dict(type="str"),
                        header_value=dict(type="str"),
                    ),
                ),
                update_interval=dict(type="int"),
                data_column=dict(type="int"),
                fields_delimiter=dict(type="str"),
                ignore_lines_that_start_with=dict(type="str"),
                json_query=dict(type="str"),
                use_gateway_proxy=dict(type="bool"),
                details_level=dict(
                    type="str", choices=["uid", "standard", "full"]
                ),
                domains_to_process=dict(type="list", elements="str"),
                ignore_warnings=dict(type="bool"),
                ignore_errors=dict(type="bool"),
            ),
        ),
        auto_publish_session=dict(type="bool"),
    )
    argument_spec.update(checkpoint_argument_spec_for_commands)

    module = AnsibleModule(argument_spec=argument_spec)

    command = "check-network-feed"

    result = api_command(module, command)
    module.exit_json(**result)


if __name__ == "__main__":
    main()



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_devices_trend_analytics_id_v1
short_description: Resource module for Network Devices Trend Analytics Id V1
description:
- Manage operation create of the resource Network Devices Trend Analytics Id V1.
- >
   The Trend analytics data for the network Device in the specified time range. The data is grouped based on the
   trend time Interval, other input parameters like attribute and aggregate attributes. For detailed information
   about the usage of the API, please refer to the Open API specification document - https //github.com/cisco-en-
   programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-
   AssuranceNetworkDevices-1.0.2-resolved.yaml.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  aggregateAttributes:
    description: Network Devices Trend Analytics Id's aggregateAttributes.
    elements: dict
    suboptions:
      function:
        description: Function.
        type: str
      name:
        description: Name.
        type: str
    type: list
  attributes:
    description: Attributes.
    elements: str
    type: list
  endTime:
    description: End Time.
    type: int
  filters:
    description: Network Devices Trend Analytics Id's filters.
    elements: dict
    suboptions:
      filters:
        description: Filters.
        elements: str
        type: list
      key:
        description: Key.
        type: str
      logicalOperator:
        description: Logical Operator.
        type: str
      operator:
        description: Operator.
        type: str
      value:
        description: Value.
        type: dict
    type: list
  groupBy:
    description: Group By.
    elements: str
    type: list
  id:
    description: Id path parameter. The device Uuid.
    type: str
  page:
    description: Network Devices Trend Analytics Id's page.
    suboptions:
      limit:
        description: Limit.
        type: int
      offset:
        description: Offset.
        type: int
      timestampOrder:
        description: Timestamp Order.
        type: str
    type: dict
  startTime:
    description: Start Time.
    type: int
  trendIntervalInMinutes:
    description: Trend Interval In Minutes.
    type: int
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for Devices TheTrendAnalyticsDataForTheNetworkDeviceInTheSpecifiedTimeRangeV1  # noqa: E501
  description: Complete reference of the TheTrendAnalyticsDataForTheNetworkDeviceInTheSpecifiedTimeRangeV1 API.  # noqa: E501
  link: https://developer.cisco.com/docs/dna-center/#!the-trend-analytics-data-for-the-network-device-in-the-specified-time-range  # noqa: E501
notes:
  - SDK Method used are
    devices.Devices.the_trend_analytics_data_for_the_network_device_in_the_specified_time_range_v1,

  - Paths used are
    post /dna/data/api/v1/networkDevices/{id}/trendAnalytics,

"""

EXAMPLES = r"""
- name: Create
  cisco.dnac.network_devices_trend_analytics_id_v1:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    aggregateAttributes:
    - function: string
      name: string
    attributes:
    - string
    endTime: 0
    filters:
    - filters:
      - string
      key: string
      logicalOperator: string
      operator: string
      value: {}
    groupBy:
    - string
    id: string
    page:
      limit: 0
      offset: 0
      timestampOrder: string
    startTime: 0
    trendIntervalInMinutes: 0

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "timestamp": 0,
          "attributes": [
            {
              "name": "string",
              "value": "string"
            }
          ],
          "aggregateAttributes": [
            {
              "name": "string",
              "function": "string",
              "value": 0
            }
          ],
          "groups": [
            {
              "id": "string",
              "attributes": [
                {
                  "name": "string",
                  "value": "string"
                }
              ],
              "aggregateAttributes": [
                {
                  "name": "string",
                  "function": "string",
                  "value": 0
                }
              ]
            }
          ]
        }
      ],
      "page": {
        "limit": 0,
        "offset": 0,
        "count": 0,
        "timestampOrder": "string"
      },
      "version": "string"
    }
"""



# -*- coding: utf-8 -*-
# Copyright 2021 Red Hat
# GNU General Public License v3.0+
# (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import absolute_import, division, print_function


__metaclass__ = type

"""
The Logging_global parser templates file. This contains
a list of parser definitions and associated functions that
facilitates both facts gathering and native command generation for
the given network resource.
"""

import re

from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.rm_base.network_template import (
    NetworkTemplate,
)


def _tmplt_logging_format(config_data):
    command = ""
    if "hostname" in config_data["format"]:
        command = "logging format hostname " + config_data["format"]["hostname"]
    if "sequence_numbers" in config_data["format"]:
        command = "logging format sequence-numbers"
    return command


def _tmplt_logging_synchronous(config_data):
    command = "logging synchronous"
    if "level" in config_data["synchronous"]:
        command += " level " + config_data["synchronous"]["level"]
    return command


def _tmplt_logging_trap(config_data):
    command = "logging trap"
    if "severity" in config_data["trap"]:
        command += " " + config_data["trap"]["severity"]
    return command


def _tmplt_logging_global_hosts(config_data):
    el = config_data["hosts"]
    command = "logging host " + el["name"]
    if el.get("add"):
        command += " add"
    if el.get("remove"):
        command += " remove"
    if el.get("port"):
        command += " " + str(el["port"])
    if el.get("protocol"):
        command += " protocol " + el["protocol"]
    return command


def _tmplt_logging_global_vrf_hosts(config_data):
    el = config_data["vrfs"]
    command = "logging vrf " + el["name"] + " host "
    el = el["hosts"]
    command += el["name"]
    if el.get("add"):
        command += " add"
    if el.get("remove"):
        command += " remove"
    if el.get("port"):
        command += " " + str(el["port"])
    if el.get("protocol"):
        command += " protocol " + el["protocol"]
    return command


def _tmplt_logging_global_format_timestamp(config_data):
    command = ""
    el = config_data["format"]["timestamp"]
    if el.get("traditional"):
        command = "logging format timestamp traditional"
        if el["traditional"].get("year"):
            if el["traditional"]["year"]:
                command += " year"
        if el["traditional"].get("timezone"):
            if el["traditional"]["timezone"]:
                command += " timezone"
    return command


class Logging_globalTemplate(NetworkTemplate):
    def __init__(self, lines=None, module=None):
        super(Logging_globalTemplate, self).__init__(
            lines=lines,
            tmplt=self,
            module=module,
        )

    # fmt: off
    PARSERS = [
        {
            "name": "buffered",
            "getval": re.compile(
                r"""
                \s*logging\sbuffered
                \s*(?P<size>\d{2,})*
                \s*(?P<sev>[0-7]|\w+)*
                $""",
                re.VERBOSE,
            ),
            "setval": 'logging buffered {{ buffered.buffer_size if buffered.buffer_size is defined }}'
                      ' {{ buffered.severity if buffered.severity is defined }}',
            "result": {
                "buffered": {
                    "buffer_size": "{{ size }}",
                    "severity": "{{ sev }}",
                },
            },
        },
        {
            "name": "console",
            "getval": re.compile(
                r"""
                \s*logging\sconsole
                \s*(?P<sev>[0-7]|\w+)*
                $""",
                re.VERBOSE,
            ),
            "setval": "logging console {{ console.severity|string if console.severity is defined else ''}}",
            "result": {
                "console": {
                    "severity": "{{ sev }}",
                },
            },
        },
        {
            "name": "event",
            "getval": re.compile(
                r"""
                \s*logging\sevent
                \s+(?P<event>link-status|port-channel|spanning-tree)
                \s*(member-status)*
                \s*global
                *$""",
                re.VERBOSE,
            ),
            "setval": "logging event {{ event }} {{ 'member-status' if event == 'port-channel' else '' }} global",
            "result": {
                "event": "{{ event }}",
            },
        },
        {
            "name": "facility",
            "getval": re.compile(
                r"""
                \s*logging\sfacility
                \s(?P<facility>\S+)
                *$""",
                re.VERBOSE,
            ),
            "setval": 'logging facility {{ facility }}',
            "result": {
                "facility": "{{ facility }}",
            },
        },
        {
            "name": "format",
            "getval": re.compile(
                r"""
                \s*logging\sformat
                \s*(?P<param>hostname\s\S+|sequence-numbers)*
                $""",
                re.VERBOSE,
            ),
            "setval": _tmplt_logging_format,
            "shared": True,
            "result": {
                "format": {
                    "hostname": '{{ param.split(" ")[1] if "hostname" in param }}',
                    "sequence_numbers": '{{ True if "sequence-numbers" in param }}',
                },
            },
        },
        {
            "name": "format.timestamp.highresolution",
            "getval": re.compile(
                r"""
                \s*logging\sformat\stimestamp\shigh-resolution
                *$""",
                re.VERBOSE,
            ),
            "setval": 'logging format timestamp high-resolution',
            "shared": True,
            "compval": "format.timestamp.high_resolution",
            "result": {
                "format": {
                    "timestamp": {
                        "high_resolution": "{{ True }}",
                    },
                },
            },
        },
        {
            "name": "format.timestamp.traditional",
            "getval": re.compile(
                r"""
                \s*logging\sformat\stimestamp\straditional
                \s*(?P<year>year)*
                \s*(?P<zone>timezone)*
                $""",
                re.VERBOSE,
            ),
            "setval": _tmplt_logging_global_format_timestamp,
            "compval": "format.timestamp.traditional",
            "shared": True,
            "result": {
                "format": {
                    "timestamp": {
                        "traditional": {
                            "year": "{{ True if year is defined}}",
                            "timezone": "{{ True if zone is defined}}",
                            "state": "{{ enabled if year and zone is undefined}}",
                        },
                    },
                },
            },
        },
        {
            "name": "host",
            "getval": re.compile(
                r"""
                \s*logging\shost
                \s*(?P<name>\S+)
                \s*(?P<oper>add|remove)*
                \s*(?P<port>\d+)*
                \s*(protocol)*
                \s*(?P<proto>tcp|udp)*
                $""",
                re.VERBOSE,
            ),
            "setval": _tmplt_logging_global_hosts,
            "compval": "hosts",
            "result": {
                "hosts": {
                    "{{ name }}": {
                        "name": "{{ name }}",
                        "add": '{{ True if oper == "add" }}',
                        "remove": '{{ True if oper == "remove" }}',
                        "port": "{{ port }}",
                        "protocol": "{{ proto }}",
                    },
                },
            },
        },
        {
            "name": "level",
            "getval": re.compile(
                r"""
                \s*logging\slevel
                \s(?P<level>\S+)
                \s(?P<sev>\S+)
                *$""",
                re.VERBOSE,
            ),
            "setval": 'logging level {{ level.facility }} {{ level.severity }}',
            "result": {
                "level": {
                    "facility": "{{ level }}",
                    "severity": "{{ sev }}",
                },
            },
        },
        {
            "name": "monitor",
            "getval": re.compile(
                r"""
                \s*logging\smonitor
                \s(?P<val>\S+)
                *$""",
                re.VERBOSE,
            ),
            "setval": 'logging monitor {{ val }}',
            "result": {
                "monitor": "{{ val }}",
            },
        },
        {
            "name": "on",
            "getval": re.compile(
                r"""
                \s*logging\son
                *$""",
                re.VERBOSE,
            ),
            "setval": 'logging on',
            "compval": 'turn_on',
            "result": {
                "turn_on": "{{ True }}",
            },
        },
        {
            "name": "persistent",
            "getval": re.compile(
                r"""
                \s*logging\spersistent
                \s*(?P<size>\d+)*
                $""",
                re.VERBOSE,
            ),
            "setval": "logging persistent{{ ' ' + persistent.size|string if persistent.size is defined }}",
            "result": {
                "persistent": {
                    "size": "{{ size }}",
                    "set": '{{ True if size is not defined }}',
                },
            },
        },
        {
            "name": "policy",
            "getval": re.compile(
                r"""
                \s*logging\spolicy\smatch
                \s*(?P<inv>inverse-result)*
                \s+match-list
                \s+(?P<match>\S+)
                \s+discard
                $""",
                re.VERBOSE,
            ),
            "setval": "logging policy match {{ 'invert-result' if policy.invert_result is defined }} match-list {{ policy.match_list }} discard",
            "result": {
                "policy": {
                    "invert_result": "{{ True if inv is defined }}",
                    "match_list": '{{ match }}',
                },
            },
        },
        {
            "name": "relogging_interval",
            "getval": re.compile(
                r"""
                \s*logging\srelogging-interval
                \s(?P<val>\d+)
                *$""",
                re.VERBOSE,
            ),
            "setval": 'logging relogging-interval {{ relogging_interval }}',
            "result": {
                "relogging_interval": "{{ val }}",
            },
        },
        {
            "name": "repeat_messages",
            "getval": re.compile(
                r"""
                \s*logging\srepeat-messages
                *$""",
                re.VERBOSE,
            ),
            "setval": 'logging repeat-messages',
            "result": {
                "repeat_messages": "{{ True }}",
            },
        },
        {
            "name": "src_interface",
            "getval": re.compile(
                r"""
                \s*logging\ssource-interface
                \s(?P<val>.+)
                *$""",
                re.VERBOSE,
            ),
            "setval": 'logging source-interface {{ source_interface }}',
            "compval": "source_interface",
            "result": {
                "source_interface": "{{ val }}",
            },
        },
        {
            "name": "synchronous",
            "getval": re.compile(
                r"""
                \s*logging\ssynchronous
                \s*(?P<level>level\s\S+)*
                $""",
                re.VERBOSE,
            ),
            "setval": _tmplt_logging_synchronous,
            "result": {
                "synchronous": {
                    "set": "{{ True if level is not defined }}",
                    "level": '{{ level.split(" ")[1] if level is defined }}',
                },
            },
        },
        {
            "name": "trap",
            "getval": re.compile(
                r"""
                \s*logging\strap
                \s*(?P<level>\S+)*
                $""",
                re.VERBOSE,
            ),
            "setval": _tmplt_logging_trap,
            "result": {
                "trap": {
                    "set": "{{ True if level is not defined }}",
                    "severity": "{{ level }}",
                },
            },
        },
        {
            "name": "vrf.host",
            "getval": re.compile(
                r"""
                \s*logging\svrf
                \s+(?P<vrf>\S+)
                \s+host
                \s(?P<name>\S+)
                \s*(?P<oper>add|remove)*
                \s*(?P<port>\d+)*
                \s*(protocol)*
                \s*(?P<proto>tcp|udp)*
                $""",
                re.VERBOSE,
            ),
            "setval": _tmplt_logging_global_vrf_hosts,
            "compval": "vrfs.hosts",
            "shared": True,
            "result": {
                "vrfs": {
                    "{{ vrf }}": {
                        "name": "{{ vrf }}",
                        "hosts": {
                            "{{ name }}": {
                                "name": "{{ name }}",
                                "add": '{{ True if oper == "add" }}',
                                "remove": '{{ True if oper == "remove" }}',
                                "port": "{{ port }}",
                                "protocol": "{{ proto }}",
                            },
                        },
                    },
                },
            },
        },
        {
            "name": "vrf.source_interface",
            "getval": re.compile(
                r"""
                \s*logging\svrf
                \s+(?P<vrf>\S+)
                \s+source-interface
                \s(?P<val>.+)
                *$""",
                re.VERBOSE,
            ),
            "setval": 'logging vrf {{ vrfs.name }} source-interface {{ vrfs.source_interface }}',
            "compval": "vrfs.source_interface",
            "shared": True,
            "result": {
                "vrfs": {
                    "{{ vrf }}": {
                        "name": "{{ vrf }}",
                        "source_interface": "{{ val }}",
                    },
                },
            },
        },
    ]
    # fmt: on



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: csr_generate
short_description: Resource module for CSR Generate
description:
- Manage operation create of the resource CSR Generate.
- Generate a certificate signing request for Multi-Use, Admin, EAP.
version_added: '1.0.0'
extends_documentation_fragment:
  - cisco.ise.module
author: Rafael Campos (@racampos)
options:
  allowWildCardCert:
    description: AllowWildCardCert flag.
    type: bool
  certificatePolicies:
    description: CSR Generate's certificatePolicies.
    type: str
  digestType:
    description: CSR Generate's digestType.
    type: str
  hostnames:
    description: CSR Generate's hostnames.
    elements: str
    type: list
  keyLength:
    description: CSR Generate's keyLength.
    type: str
  keyType:
    description: CSR Generate's keyType.
    type: str
  portalGroupTag:
    description: CSR Generate's portalGroupTag.
    type: str
  sanDNS:
    description: CSR Generate's sanDNS.
    elements: str
    type: list
  sanDir:
    description: CSR Generate's sanDir.
    elements: str
    type: list
  sanIP:
    description: CSR Generate's sanIP.
    elements: str
    type: list
  sanURI:
    description: CSR Generate's sanURI.
    elements: str
    type: list
  subjectCity:
    description: CSR Generate's subjectCity.
    type: str
  subjectCommonName:
    description: CSR Generate's subjectCommonName.
    type: str
  subjectCountry:
    description: CSR Generate's subjectCountry.
    type: str
  subjectOrg:
    description: CSR Generate's subjectOrg.
    type: str
  subjectOrgUnit:
    description: CSR Generate's subjectOrgUnit.
    type: str
  subjectState:
    description: CSR Generate's subjectState.
    type: str
  usedFor:
    description: CSR Generate's usedFor.
    type: str
requirements:
- ciscoisesdk >= 2.2.3
- python >= 3.5
seealso:
- name: Cisco ISE documentation for Certificates
  description: Complete reference of the Certificates API.
  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!certificate-openapi
notes:
  - SDK Method used are
    certificates.Certificates.generate_csr,

  - Paths used are
    post /api/v1/certs/certificate-signing-request,

"""

EXAMPLES = r"""
- name: Create
  cisco.ise.csr_generate:
    ise_hostname: "{{ise_hostname}}"
    ise_username: "{{ise_username}}"
    ise_password: "{{ise_password}}"
    ise_verify: "{{ise_verify}}"
    allowWildCardCert: true
    certificatePolicies: string
    digestType: string
    hostnames:
    - string
    keyLength: string
    keyType: string
    portalGroupTag: string
    sanDNS:
    - string
    sanDir:
    - string
    sanIP:
    - string
    sanURI:
    - string
    subjectCity: string
    subjectCommonName: string
    subjectCountry: string
    subjectOrg: string
    subjectOrgUnit: string
    subjectState: string
    usedFor: string

"""

RETURN = r"""
ise_response:
  description: A dictionary or list with the response returned by the Cisco ISE Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "link": {
            "href": "string",
            "rel": "string",
            "type": "string"
          },
          "message": "string"
        }
      ],
      "version": "string"
    }
"""



# -*- coding: utf-8 -*-
# Copyright 2021 Red Hat
# GNU General Public License v3.0+
# (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import absolute_import, division, print_function


__metaclass__ = type

#############################################
#                WARNING                    #
#############################################
#
# This file is auto generated by the
# cli_rm_builder.
#
# Manually editing this file is not advised.
#
# To update the argspec make the desired changes
# in the module docstring and re-run
# cli_rm_builder.
#
#############################################

"""
The arg spec for the iosxr_bgp_address_family module
"""


class Bgp_address_familyArgs(object):  # pylint: disable=R0903
    """The arg spec for the iosxr_bgp_address_family module"""

    def __init__(self, **kwargs):
        pass

    argument_spec = {
        "config": {
            "type": "dict",
            "options": {
                "as_number": {"type": "str"},
                "address_family": {
                    "type": "list",
                    "elements": "dict",
                    "options": {
                        "afi": {
                            "type": "str",
                            "choices": [
                                "ipv4",
                                "ipv6",
                                "l2vpn",
                                "link-state",
                                "vpnv4",
                                "vpnv6",
                            ],
                        },
                        "safi": {
                            "type": "str",
                            "choices": [
                                "flowspec",
                                "mdt",
                                "multicast",
                                "mvpn",
                                "rt-filter",
                                "tunnel",
                                "unicast",
                                "evpn",
                                "mspw",
                                "vpls-vpws",
                                "link-state",
                            ],
                        },
                        "vrf": {"type": "str"},
                        "additional_paths": {
                            "type": "str",
                            "choices": ["send", "receive"],
                        },
                        "advertise_best_external": {"type": "bool"},
                        "aggregate_address": {
                            "type": "list",
                            "elements": "dict",
                            "options": {
                                "value": {"type": "str"},
                                "as_set": {"type": "bool"},
                                "as_confed_set": {"type": "bool"},
                                "summary_only": {"type": "bool"},
                                "route_policy": {"type": "str"},
                            },
                        },
                        "allocate_label": {
                            "type": "dict",
                            "options": {
                                "all": {"type": "bool"},
                                "route_policy": {"type": "str"},
                            },
                        },
                        "as_path_loopcheck_out_disable": {"type": "bool"},
                        "bgp": {
                            "type": "dict",
                            "options": {
                                "attribute_download": {"type": "bool"},
                                "bestpath": {
                                    "type": "dict",
                                    "options": {
                                        "origin_as": {
                                            "type": "dict",
                                            "options": {
                                                "use": {
                                                    "type": "dict",
                                                    "options": {
                                                        "validity": {
                                                            "type": "bool",
                                                        },
                                                    },
                                                },
                                                "allow": {
                                                    "type": "dict",
                                                    "options": {
                                                        "invalid": {
                                                            "type": "bool",
                                                        },
                                                    },
                                                },
                                            },
                                        },
                                    },
                                },
                                "client_to_client": {
                                    "type": "dict",
                                    "options": {
                                        "reflection": {
                                            "type": "dict",
                                            "options": {
                                                "cluster_id_disable": {
                                                    "type": "dict",
                                                    "options": {
                                                        "cluster_id": {
                                                            "type": "str",
                                                        },
                                                        "disable": {
                                                            "type": "bool",
                                                        },
                                                    },
                                                },
                                                "disable": {"type": "bool"},
                                            },
                                        },
                                    },
                                },
                                "dampening": {
                                    "type": "dict",
                                    "mutually_exclusive": [
                                        ["set", "value", "route_policy"],
                                    ],
                                    "options": {
                                        "set": {"type": "bool"},
                                        "value": {"type": "int"},
                                        "route_policy": {"type": "str"},
                                    },
                                },
                                "label_delay": {
                                    "type": "dict",
                                    "options": {
                                        "delay_second_parts": {"type": "int"},
                                        "delay_ms_parts": {"type": "int"},
                                    },
                                },
                                "import_delay": {
                                    "type": "dict",
                                    "options": {
                                        "delay_second_parts": {"type": "int"},
                                        "delay_ms_parts": {"type": "int"},
                                    },
                                },
                                "origin_as": {
                                    "type": "dict",
                                    "options": {
                                        "validation": {
                                            "type": "dict",
                                            "options": {
                                                "disable": {"type": "bool"},
                                                "signal": {
                                                    "type": "dict",
                                                    "options": {
                                                        "ibgp": {
                                                            "type": "bool",
                                                        },
                                                    },
                                                },
                                            },
                                        },
                                    },
                                },
                                "scan_time": {"type": "int"},
                            },
                        },
                        "default_martian_check_disable": {"type": "bool"},
                        "distance": {
                            "type": "dict",
                            "options": {
                                "routes_external_to_as": {"type": "int"},
                                "routes_internal_to_as": {"type": "int"},
                                "local_routes": {"type": "int"},
                            },
                        },
                        "dynamic_med": {"type": "int"},
                        "maximum_paths": {
                            "type": "dict",
                            "options": {
                                "ibgp": {
                                    "type": "dict",
                                    "options": {
                                        "max_path_value": {"type": "int"},
                                        "order_igp_metric": {"type": "bool"},
                                        "selective_order_igp_metric": {
                                            "type": "bool",
                                        },
                                        "unequal_cost": {
                                            "type": "dict",
                                            "options": {
                                                "set": {"type": "bool"},
                                                "order_igp_metric": {
                                                    "type": "bool",
                                                },
                                                "selective_order_igp_metric": {
                                                    "type": "bool",
                                                },
                                            },
                                        },
                                    },
                                },
                                "ebgp": {
                                    "type": "dict",
                                    "options": {
                                        "max_path_value": {"type": "int"},
                                        "order_igp_metric": {"type": "bool"},
                                        "selective_order_igp_metric": {
                                            "type": "bool",
                                        },
                                    },
                                },
                                "eibgp": {
                                    "type": "dict",
                                    "options": {
                                        "max_path_value": {"type": "int"},
                                        "order_igp_metric": {"type": "bool"},
                                        "selective_order_igp_metric": {
                                            "type": "bool",
                                        },
                                    },
                                },
                            },
                        },
                        "networks": {
                            "type": "list",
                            "elements": "dict",
                            "options": {
                                "network": {"type": "str"},
                                "backdoor_route_policy": {"type": "str"},
                                "route_policy": {"type": "str"},
                            },
                        },
                        "nexthop": {
                            "type": "dict",
                            "options": {
                                "resolution_prefix_length_minimum": {
                                    "type": "int",
                                    "choices": [0, 32],
                                },
                                "route_policy": {"type": "str"},
                                "trigger_delay_critical": {"type": "int"},
                                "trigger_delay_non_critical": {"type": "int"},
                            },
                        },
                        "optimal_route_reflection": {
                            "type": "dict",
                            "options": {
                                "group_name": {"type": "str"},
                                "primary_address": {"type": "str"},
                                "secondary_address": {"type": "str"},
                            },
                        },
                        "permanent_network_route_policy": {"type": "str"},
                        "retain_local_label": {"type": "int"},
                        "table_policy": {"type": "str"},
                        "update": {
                            "type": "dict",
                            "options": {
                                "limit": {
                                    "type": "dict",
                                    "options": {
                                        "sub_group": {
                                            "type": "dict",
                                            "options": {
                                                "ibgp": {"type": "int"},
                                                "ebgp": {"type": "int"},
                                            },
                                        },
                                        "address_family": {"type": "int"},
                                    },
                                },
                                "wait_install": {"type": "bool"},
                            },
                        },
                        "redistribute": {
                            "type": "list",
                            "elements": "dict",
                            "options": {
                                "protocol": {
                                    "type": "str",
                                    "choices": [
                                        "ospf",
                                        "application",
                                        "eigrp",
                                        "isis",
                                        "static",
                                        "connected",
                                        "lisp",
                                        "mobile",
                                        "rip",
                                        "subscriber",
                                    ],
                                    "required": True,
                                },
                                "id": {"type": "str"},
                                "metric": {"type": "int"},
                                "route_policy": {"type": "str"},
                                "internal": {"type": "bool"},
                                "external": {"type": "bool"},
                                "level": {
                                    "type": "str",
                                    "choices": ["1", "2", "1-inter-area"],
                                },
                                "nssa_external": {"type": "bool"},
                                "external_ospf": {
                                    "type": "int",
                                    "choices": [1, 2],
                                },
                            },
                        },
                        "inter_as_install": {"type": "bool"},
                        "segmented_multicast": {"type": "bool"},
                        "global_table_multicast": {"type": "bool"},
                        "vrf_all_conf": {
                            "type": "dict",
                            "options": {
                                "source_rt_import_policy": {"type": "bool"},
                                "table_policy": {"type": "str"},
                                "label_mode": {
                                    "type": "dict",
                                    "options": {
                                        "per_ce": {"type": "bool"},
                                        "per_vrf": {"type": "bool"},
                                        "route_policy": {"type": "str"},
                                    },
                                },
                            },
                        },
                        "weight": {
                            "type": "dict",
                            "options": {
                                "reset_on_import_disable": {"type": "bool"},
                                "reset_on_import": {"type": "bool"},
                            },
                        },
                        "allow_vpn_default_originate": {"type": "bool"},
                        "label_mode": {
                            "type": "dict",
                            "options": {
                                "per_ce": {"type": "bool"},
                                "per_vrf": {"type": "bool"},
                                "route_policy": {"type": "str"},
                                "per_prefix": {"type": "bool"},
                            },
                        },
                        "mvpn_single_forwarder_selection_all": {
                            "type": "bool",
                        },
                        "mvpn_single_forwarder_selection_highest_ip_address": {
                            "type": "bool",
                        },
                        "route_target_download": {"type": "bool"},
                    },
                },
            },
        },
        "running_config": {"type": "str"},
        "state": {
            "type": "str",
            "choices": [
                "deleted",
                "merged",
                "overridden",
                "replaced",
                "gathered",
                "rendered",
                "parsed",
            ],
            "default": "merged",
        },
    }  # pylint: disable=C0301
